@@ -11,10 +11,6 @@ def __init__(hub):
     Set up variables used by the log subsystem
     """
     logging.addLevelName(5, "TRACE")
-    hub.log.LOGGER = {
-        # Initialize the root logger
-        "": logging.getLogger()
-    }
     hub.log.LEVEL = {
         "notset": logging.NOTSET,
         "trace": 5,
@@ -26,13 +22,14 @@ def __init__(hub):
         "fatal": logging.FATAL,
         "critical": logging.CRITICAL,
     }
+    log = logging.getLogger(__name__)
 
     # These should be overwritten by the integrated logger, but here's a contingency
-    hub.log.INT_LEVEL = logging.INFO
-    hub.log.log = hub.log.LOGGER[""].log
-    hub.log.trace = lambda *args, **kwargs: hub.log.LOGGER[""].log(5, *args, **kwargs)
-    hub.log.debug = hub.log.LOGGER[""].debug
-    hub.log.info = hub.log.LOGGER[""].info
-    hub.log.critical = hub.log.LOGGER[""].critical
-    hub.log.warning = hub.log.LOGGER[""].warning
-    hub.log.error = hub.log.LOGGER[""].error
+    hub.log.INT_LEVEL = log.getEffectiveLevel()
+    hub.log.log = log.log
+    hub.log.trace = lambda msg, *args, **kwargs: log.log(5, msg, *args, **kwargs)
+    hub.log.debug = log.debug
+    hub.log.info = log.info
+    hub.log.critical = log.critical
+    hub.log.warning = log.warning
+    hub.log.error = log.error
